@@ -1,7 +1,7 @@
 use crate::node::{Node, NodeContainer};
 use std::borrow::BorrowMut;
 use crate::DefaultModifiers;
-use crate::renderer::{Renderable};
+use crate::{Renderable};
 
 #[derive(Debug, Clone)]
 pub struct Image {
